# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/client/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bibc/core/client/v1/tx.proto\x12\x12ibc.core.client.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1fibc/core/client/v1/client.proto\"\x91\x01\n\x0fMsgCreateClient\x12*\n\x0c\x63lient_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12-\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x19\n\x17MsgCreateClientResponse\"w\n\x0fMsgUpdateClient\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12,\n\x0e\x63lient_message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x19\n\x17MsgUpdateClientResponse\"\xea\x01\n\x10MsgUpgradeClient\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12*\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12-\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x1c\n\x14proof_upgrade_client\x18\x04 \x01(\x0c\x12%\n\x1dproof_upgrade_consensus_state\x18\x05 \x01(\x0c\x12\x0e\n\x06signer\x18\x06 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1a\n\x18MsgUpgradeClientResponse\"\x87\x01\n\x15MsgSubmitMisbehaviour\x12\x15\n\tclient_id\x18\x01 \x01(\tB\x02\x18\x01\x12.\n\x0cmisbehaviour\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x02\x18\x01\x12\x12\n\x06signer\x18\x03 \x01(\tB\x02\x18\x01:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgSubmitMisbehaviourResponse\"f\n\x0fMsgUpdateParams\x12\x11\n\tauthority\x18\x01 \x01(\t\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32\x1a.ibc.core.client.v1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\x91\x04\n\x03Msg\x12`\n\x0c\x43reateClient\x12#.ibc.core.client.v1.MsgCreateClient\x1a+.ibc.core.client.v1.MsgCreateClientResponse\x12`\n\x0cUpdateClient\x12#.ibc.core.client.v1.MsgUpdateClient\x1a+.ibc.core.client.v1.MsgUpdateClientResponse\x12\x63\n\rUpgradeClient\x12$.ibc.core.client.v1.MsgUpgradeClient\x1a,.ibc.core.client.v1.MsgUpgradeClientResponse\x12r\n\x12SubmitMisbehaviour\x12).ibc.core.client.v1.MsgSubmitMisbehaviour\x1a\x31.ibc.core.client.v1.MsgSubmitMisbehaviourResponse\x12\x66\n\x12UpdateClientParams\x12#.ibc.core.client.v1.MsgUpdateParams\x1a+.ibc.core.client.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42:Z8github.com/cosmos/ibc-go/v7/modules/core/02-client/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/cosmos/ibc-go/v7/modules/core/02-client/types'
  _MSGCREATECLIENT._options = None
  _MSGCREATECLIENT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGUPDATECLIENT._options = None
  _MSGUPDATECLIENT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGUPGRADECLIENT._options = None
  _MSGUPGRADECLIENT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['client_id']._options = None
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['client_id']._serialized_options = b'\030\001'
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['misbehaviour']._options = None
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['misbehaviour']._serialized_options = b'\030\001'
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['signer']._options = None
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['signer']._serialized_options = b'\030\001'
  _MSGSUBMITMISBEHAVIOUR._options = None
  _MSGSUBMITMISBEHAVIOUR._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGCREATECLIENT._serialized_start=159
  _MSGCREATECLIENT._serialized_end=304
  _MSGCREATECLIENTRESPONSE._serialized_start=306
  _MSGCREATECLIENTRESPONSE._serialized_end=331
  _MSGUPDATECLIENT._serialized_start=333
  _MSGUPDATECLIENT._serialized_end=452
  _MSGUPDATECLIENTRESPONSE._serialized_start=454
  _MSGUPDATECLIENTRESPONSE._serialized_end=479
  _MSGUPGRADECLIENT._serialized_start=482
  _MSGUPGRADECLIENT._serialized_end=716
  _MSGUPGRADECLIENTRESPONSE._serialized_start=718
  _MSGUPGRADECLIENTRESPONSE._serialized_end=744
  _MSGSUBMITMISBEHAVIOUR._serialized_start=747
  _MSGSUBMITMISBEHAVIOUR._serialized_end=882
  _MSGSUBMITMISBEHAVIOURRESPONSE._serialized_start=884
  _MSGSUBMITMISBEHAVIOURRESPONSE._serialized_end=915
  _MSGUPDATEPARAMS._serialized_start=917
  _MSGUPDATEPARAMS._serialized_end=1019
  _MSGUPDATEPARAMSRESPONSE._serialized_start=1021
  _MSGUPDATEPARAMSRESPONSE._serialized_end=1046
  _MSG._serialized_start=1049
  _MSG._serialized_end=1578
# @@protoc_insertion_point(module_scope)
